@@ -72,9 +72,9 @@ int pth_cancel(pth_t thread)
 
         /* remove thread from its queue */
         switch (thread->state) {
-            case PTH_STATE_NEW:     q = &pth_NQ;
-            case PTH_STATE_READY:   q = &pth_RQ;
-            case PTH_STATE_WAITING: q = &pth_WQ;
+            case PTH_STATE_NEW:     q = &pth_NQ; break;
+            case PTH_STATE_READY:   q = &pth_RQ; break;
+            case PTH_STATE_WAITING: q = &pth_WQ; break;
             default:                q = NULL;
         }
         if (q == NULL)
