@@ -59,7 +59,7 @@ intern void pth_debug(char *file, int line, char *fmt, ...)
 
     errno_preserve;
     va_start(ap, fmt);
-    sprintf(str, "%d:%s:%04d: ", getpid(), file, line);
+    sprintf(str, "%d:%s:%04d: ", (int)getpid(), file, line);
     n = strlen(str);
     vsprintf(str+n, fmt, ap);
     va_end(ap);
