@@ -50,5 +50,5 @@
 
 #endif /* cpp */
 
-intern int pth_errno_storage;
+intern int pth_errno_storage = 0;
 
