@@ -63,26 +63,20 @@ intern int pth_ring_elements(pth_ring_t *r)
     return n;
 }
 
-intern pth_ringnode_t *pth_ring_next(pth_ring_t *r, pth_ringnode_t *rn)
-{
-    if (r == NULL || rn == NULL)
-        return NULL;
-    return rn->rn_next;
-}
+#if cpp
+#define pth_ring_next(r, rn) \
+    (((r) == NULL || (rn) == NULL) ? NULL : (rn)->rn_next)
+#endif
 
-intern pth_ringnode_t *pth_ring_prev(pth_ring_t *r, pth_ringnode_t *rn)
-{
-    if (r == NULL || rn == NULL)
-        return NULL;
-    return rn->rn_prev;
-}
+#if cpp
+#define pth_ring_prev(r, rn) \
+    (((r) == NULL || (rn) == NULL) ? NULL : (rn)->rn_prev)
+#endif
 
-intern pth_ringnode_t *pth_ring_first(pth_ring_t *r)
-{
-    if (r == NULL)
-        return NULL;
-    return r->rn_hook;
-}
+#if cpp
+#define pth_ring_first(r) \
+    ((r) == NULL ? NULL : (r)->rn_hook)
+#endif
 
 intern pth_ringnode_t *pth_ring_last(pth_ring_t *r)
 {
@@ -169,17 +163,15 @@ intern void pth_ring_append(pth_ring_t *r, pth_ringnode_t *rn)
     return;
 }
 
-intern void pth_ring_push(pth_ring_t *r, pth_ringnode_t *rn)
-{
-    pth_ring_prepend(r, rn);
-    return;
-}
+#if cpp
+#define pth_ring_push(r, rn) \
+    pth_ring_prepend((r), (rn))
+#endif
 
-intern void pth_ring_unshift(pth_ring_t *r, pth_ringnode_t *rn)
-{
-    pth_ring_append(r, rn);
-    return;
-}
+#if cpp
+#define pth_ring_unshift(r, rn) \
+    pth_ring_append((r), (rn))
+#endif
 
 intern pth_ringnode_t *pth_ring_pop(pth_ring_t *r)
 {
