@@ -21,7 +21,9 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
-
+                             /* ``Premature optimization is 
+                                  the root of all evil.''
+                                             -- D.E.Knuth */
 #include "pth_p.h"
 
 /* calculate numerical mimimum */
@@ -96,7 +98,7 @@ intern void pth_util_fds_merge(int nfd,
 {
     register int s;
 
-    for (s = 0; s <= nfd-1; s++) {
+    for (s = 0; s < nfd; s++) {
         if (ifds1 != NULL)
             if (FD_ISSET(s, ifds1))
                 FD_SET(s, ofds1);
@@ -118,7 +120,7 @@ intern int pth_util_fds_test(int nfd,
 {
     register int s;
 
-    for (s = 0; s <= nfd-1; s++) {
+    for (s = 0; s < nfd; s++) {
         if (ifds1 != NULL)
             if (FD_ISSET(s, ifds1) && FD_ISSET(s, ofds1))
                 return TRUE;
@@ -146,7 +148,7 @@ intern int pth_util_fds_select(int nfd,
     register int n;
 
     n = 0;
-    for (s = 0; s <= nfd-1; s++) {
+    for (s = 0; s < nfd; s++) {
         if (ifds1 != NULL && FD_ISSET(s, ifds1)) {
             if (!FD_ISSET(s, ofds1))
                FD_CLR(s, ifds1);
